Numerox examples
================

- Make a `model`_
- Your `first tournament`_
- `Backtest`_ example
- The `run and splitter`_ functions
- `Compare model`_ performances
- Manipulate `data`_
- `Transform features`_ (``data.x``)
- Calculate `concordance`_
- `Run multiple models`_ through a single data splitter
- Numerai's `CV warning`_ (hold out eras not rows)


.. _model: https://github.com/kwgoodman/numerox/blob/master/numerox/model.py
.. _first tournament: https://github.com/kwgoodman/numerox/blob/master/examples/first_tournament.py
.. _backtest: https://github.com/kwgoodman/numerox/blob/master/examples/backtest_example.py
.. _run and splitter: https://github.com/kwgoodman/numerox/blob/master/examples/run.rst
.. _compare model: https://github.com/kwgoodman/numerox/blob/master/examples/compare_models.rst
.. _data: https://github.com/kwgoodman/numerox/blob/master/examples/data.rst
.. _Transform features: https://github.com/kwgoodman/numerox/blob/master/examples/transform.rst
.. _concordance: https://github.com/kwgoodman/numerox/blob/master/examples/concordance_example.py
.. _run multiple models: https://github.com/kwgoodman/numerox/blob/master/examples/runner_example.py
.. _cv warning: https://github.com/kwgoodman/numerox/blob/master/examples/cv_warning.rst
